@@ -335,6 +335,10 @@ private:
   std::unique_ptr<OAuthRedirectEndpoint> redirectEndpoint_;
   std::unique_ptr<Http::Client> httpClient_;
 
+  // onOAuthDone() gets called from WApplication::unsuspended(), keeping
+  // the connection object allows us to disconnect after it's done
+  Wt::Signals::connection doneCallbackConnection_;
+
   void requestToken(const std::string& authorizationCode);
   void handleToken(AsioWrapper::error_code err,
 		   const Http::Message& response);
@@ -458,6 +462,21 @@ public:
   virtual std::unique_ptr<OAuthProcess>
     createProcess(const std::string& scope) const = 0;
 
+  /*! \brief Configure if a popup should be used for the login.
+   *
+   * When set to false, the session will be suspended when the login starts,
+   * allowing the state to be restored when it completes.
+   * A timeout can be configured in wt_config.xml (see <tt>oauth2-redirect-timeout</tt>).
+   *
+   * The default value is true. When JavaScript is not available, a redirect without
+   * popup is always used.
+   */
+  void setPopupEnabled(bool enable);
+
+  /*! \brief Returns if a popup is used for the login.
+   */
+  bool popupEnabled() const;
+
   /*! \brief Returns the provider name.
    *
    * This is a short identifier.
@@ -619,6 +638,8 @@ private:
 
   struct Impl;
   std::unique_ptr<Impl> impl_;
+
+  bool usePopup_;
 };
 
   }
