@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -181,7 +181,7 @@ public:
 #ifndef WT_TARGET_JAVA
   typedef std::map<ItemDataRole, cpp17::any> DataMap;
 #else
-  typedef std::treemap<int, cpp17::any> DataMap;
+  typedef std::treemap<ItemDataRole, cpp17::any> DataMap;
 #endif
 
   /*! \brief Creates a new data model.
@@ -255,9 +255,7 @@ public:
    */
   virtual WModelIndex parent(const WModelIndex& index) const = 0;
 
-  /*! \brief Returns data at a specific model index.
-   *
-   * Return data for a given role at a given index.
+  /*! \brief Returns data at a specified model index for the given role.
    *
    * You should check the \p role to decide what data to
    * return. Usually a View class will ask for data for several roles
@@ -480,7 +478,7 @@ public:
   /*! \brief Expands a column.
    *
    * Expands a column. This may only be called by a view when the
-   * Wt::MatchFlag::ColumnIsCollapsed flag is set.
+   * Wt::HeaderFlag::ColumnIsCollapsed flag is set.
    *
    * The default implementation does nothing.
    *
@@ -491,7 +489,7 @@ public:
   /*! \brief Collapses a column.
    *
    * Collapses a column. This may only be called by a view when the
-   * Wt::MatchFlag::ColumnIsExpandedLeft or Wt::MatchFlag::ColumnIsExpandedRight flag is set.
+   * Wt::HeaderFlag::ColumnIsExpandedLeft or Wt::HeaderFlag::ColumnIsExpandedRight flag is set.
    *
    * The default implementation does nothing.
    *
@@ -557,6 +555,12 @@ public:
    * abstract item models. Source item data is copied (but not the
    * source item's flags).
    *
+   * This method is overloaded for handling drop events on top of items
+   * or drop events between items (see Wt::DropLocation). This overload
+   * handles drops on top of items, but note that due to historical
+   * reasons it will also insert the items in between when called with
+   * DropAction::Move.
+   *
    * The location in the model is indicated by the \p row and
    * \p column within the \p parent index. If \p row is
    * -1, then the item is appended to the \p parent. Otherwise,
@@ -577,6 +581,29 @@ public:
   virtual void dropEvent(const WDropEvent& e, DropAction action,
 			 int row, int column, const WModelIndex& parent);
 
+  /*! \brief Handles a drop event.
+   *
+   * The default implementation only handles generic drag&drop between
+   * abstract item models. Source item data is copied (but not the
+   * source item's flags).
+   *
+   * This method is overloaded for handling drop events on top of items
+   * or drop events between items. This overload handles drops between
+   * items. The drop was received relative to the \p index item and the \p side
+   * parameter will only be Wt::Top or Wt::Bottom.
+   *
+   * You may want to reimplement this method if you want to handle
+   * other mime-type data, or if you want to refine how the drop event
+   * of an item selection must be interpreted.
+   *
+   * \note Currently, only row selections are handled by the default
+   *       implementation.
+   *
+   * \sa mimeType(), WItemSelectionModel
+   */
+  virtual void dropEvent(const WDropEvent& e, DropAction action,
+                         const WModelIndex& index, Wt::Side side);
+
   /*! \brief Inserts one column.
    *
    * This is a convenience method that adds a single column, and is
