@@ -3,17 +3,17 @@
 
 // Version defines
 #define WT_SERIES 4
-#define WT_MAJOR  5
-#define WT_MINOR  0
+#define WT_MAJOR  6
+#define WT_MINOR  1
 
 /*! \brief A constant that encodes the library version of %Wt
  *
  * You may use this constant to check for the version of %Wt at build-time.
  */
 #define WT_VERSION (((WT_SERIES & 0xff) << 24) | ((WT_MAJOR & 0xff) << 16) | ((WT_MINOR & 0xff) << 8))
-#define WT_VERSION_STR "4.5.0"
-#define WT_CLASS       "Wt4_5_0"
-#define WT_INCLUDED_VERSION Wt_4_5_0
+#define WT_VERSION_STR "4.6.1"
+#define WT_CLASS       "Wt4_6_1"
+#define WT_INCLUDED_VERSION Wt_4_6_1
 
 #define RUNDIR "/var/run/wt"
 #define WT_CONFIG_XML "/etc/wt/wt_config.xml"
@@ -31,6 +31,7 @@
 #define WT_HAS_WRASTERIMAGE
 #define WT_HAS_WPDFIMAGE
 #define WT_WITH_SSL
+/* #undef WT_HAS_SAML */
 
 #define WT_USE_OPENGL
 /* #undef WT_DEBUG_ENABLED */
@@ -40,6 +41,9 @@
 /* #undef WT_ANY_IS_EXPERIMENTAL_ANY */
 /* #undef WT_ANY_IS_STD_ANY */
 
+#define WT_DATE_TZ_USE_DATE
+/* #undef WT_DATE_TZ_USE_STD */
+
 #define WT_ASIO_IS_BOOST_ASIO
 /* #undef WT_ASIO_IS_STANDALONE_ASIO */
 
